@@ -2,9 +2,10 @@
 
 import os
 import time
+import sys
 import docker
-import psutil
 import subprocess
+import gdown
 
 from GangaCore.Utility import logging
 from GangaCore.Utility.Config import getConfig
@@ -15,7 +16,7 @@ from GangaCore.Utility.Virtualization import (
     checkSingularity, installUdocker
 )
 from GangaCore.Utility.Config import get_unique_name, get_unique_port
-
+from GangaCore.Utility.Decorators import repeat_while_none
 
 logger = logging.getLogger()
 UDOCKER_LOC = os.path.expanduser(getConfig("Configuration")["UDockerlocation"])
@@ -38,6 +39,44 @@ class ContainerCommandError(Exception):
         return f"[{self.controller}]: Errored with {self.message}"
 
 
+def mongo_processes():
+    """
+    Lists all the running processes on the system
+    """
+    status_command = "ps -aux | grep mongod"
+    output = subprocess.Popen(
+        ['ps', 'aux'],
+        stdout=subprocess.PIPE
+    ).stdout.readlines()
+    output = [i.decode("utf-8") for i in output]
+    headers = [h for h in ' '.join(output[0].strip().split()).split() if h]
+    raw_data = map(
+        lambda s:
+        s.strip().split(None, len(headers) - 1), output[1:]
+    )
+    procs = [dict(zip(headers, r)) for r in raw_data]
+
+    # check if the program is related to mongo
+    mongo_procs = [proc for proc in procs if "mongo" in proc["COMMAND"]]
+    for idx in range(len(mongo_procs)):
+        mongo_procs[idx]["environ"] = get_proc_environ(mongo_procs[idx]["PID"])
+
+    return mongo_procs
+
+
+def get_proc_environ(pid):
+    """
+    Get environ information from the proc/pid/environ
+    """
+    output = subprocess.Popen(
+        ["cat", f"/proc/{pid}/environ"],
+        stdout=subprocess.PIPE
+    ).stdout.readlines()
+    output = [i.decode("utf-8") for i in output]
+
+    return " ".join(output)
+
+
 def checkNative():
     """
     Check if the mongo database is instanlled locally
@@ -55,6 +94,7 @@ def checkNative():
         return True
     return False
 
+
 def get_database_config(gangadir):
     """
     Generate the requried variables for database config
@@ -62,13 +102,14 @@ def get_database_config(gangadir):
 
     """
     values_to_copy = ["controller", "host",
-                        "baseImage", "username", "password"]
+                      "baseImage", "username", "password"]
     logger = getLogger()
     config = dict([
         (key, getConfig("DatabaseConfiguration")[key])
         for key in values_to_copy
     ])
-    container_config_loc = os.path.join(getConfig("Configuration")['gangadir'], "container.rc")
+    container_config_loc = os.path.join(getConfig("Configuration")[
+                                        'gangadir'], "container.rc")
 
     if gangadir:
         container_config_loc = os.path.join(gangadir, "container.rc")
@@ -117,42 +158,60 @@ def mongod_exists(controller, cname=None):
             f"Not Implemented for controller of type: {controller}"
         )
 
-    procs = [proc for proc in psutil.process_iter() if proc.name() == "mongod"]
+    all_procs = mongo_processes()
+    procs = [proc for proc in all_procs]
     for proc in procs:
-        proc_dict = proc.as_dict()
-        if "environ" in proc_dict and proc_dict["environ"]:
-            if controller == "udocker":
-                if (
-                    cname
-                    and "container_names" in proc_dict["environ"]
-                    and proc_dict["environ"]["container_names"] == cname
-                ):
-                    return proc
-                if ["container_uuid", "container_root", "container_names"] in list(
-                    proc_dict["environ"].keys()
-                ):
-                    return proc
-            elif controller == "singularity":
-                if "SINGULARITY_CONTAINER" in proc_dict["environ"]:
-                    if proc_dict["environ"]["SINGULARITY_CONTAINER"] == cname:
-                        return proc
+        if controller == "udocker":
+            if (
+                cname
+                and "container_names" in proc["environ"]
+                and cname in proc["environ"]
+            ):
+                return proc
+        elif controller == "singularity":
+            if "SINGULARITY_CONTAINER" in proc["environ"] and cname in proc["environ"]:
+                return proc
     return None
 
 
+@repeat_while_none(max=10, message='Waiting for Mongo DB to start')
+def mongod_exists_wait(controller, cname=None):
+    return mongod_exists(controller, cname)
+
+
+def check_sif_file_hash(path):
+    """Check the hash of the sif file used by singularity
+    Args:
+        path (str): Location of the sif file
+    """
+    import hashlib
+
+    DEF_HASH = "a3833a7eb669f21f27de130495e2e1ba"
+
+    m = hashlib.md5()
+    hashfile = open(path, "rb")
+    while True:
+        data = hashfile.read(4*1024*1024)
+        if not data:
+            break
+        m.update(data)
+    hashedMd5 = m.hexdigest()
+
+    if DEF_HASH == hashedMd5:
+        return True
+    else:
+        return False
+
+
 def download_mongo_sif(path):
     """
     Download and save the mongo.sif file in the path
     """
-    import gdown  # download the required sif file
+    os.makedirs(path, exist_ok=True)
     url = 'https://cernbox.cern.ch/index.php/s/fv37NbLf24FpoWY/download'
-    output = 'mongo.sif'
-    gdown.download(url, output, quiet=False)
+    fname = os.path.join(path, 'mongo.sif')
 
-    import shutil  # copy the files from repository to testing directory
-    shutil.copy(
-        src="mongo.sif",
-        dst=path
-    )
+    gdown.download(url, fname, quiet=False)
 
 
 def create_mongodir(gangadir):
@@ -205,13 +264,15 @@ def singularity_handler(database_config, action, gangadir):
         # )
 
     bind_loc = create_mongodir(gangadir=gangadir)
-    start_container = f"""singularity run \
+    start_container = f"""env MONGO_SIF={sif_file} \
+    singularity --quiet run \
     --bind {bind_loc}:/data \
     {sif_file} mongod \
     --port {database_config['port']} \
     --logpath {gangadir}/logs/mongod-ganga.log"""
 
-    stop_container = f"""singularity run \
+    stop_container = f"""env MONGO_SIF={sif_file} \
+    singularity --quiet run \
     --bind {bind_loc}:/data \
     {sif_file} mongod --port {database_config['port']} --shutdown"""
 
@@ -220,11 +281,20 @@ def singularity_handler(database_config, action, gangadir):
     if action not in ["start", "quit"]:
         raise NotImplementedError(f"Illegal Opertion on container")
 
+    has_correct_hash = check_sif_file_hash(sif_file)
+    if not has_correct_hash:
+        import sys
+        logger.fatal((
+            f"sif_file at {sif_file} does not match the expected hash." +
+            " Delete it to automatically download the correct file."
+        ))
+        sys.exit(1)
+
     if action == "start":
         proc_status = mongod_exists(controller="singularity", cname=sif_file)
         if proc_status is None:
             logger.debug(
-                "starting singularity container using command: ", start_container)
+                f"Starting singularity container using command: {start_container}")
             proc = subprocess.Popen(
                 start_container,
                 shell=True,
@@ -232,11 +302,12 @@ def singularity_handler(database_config, action, gangadir):
                 stdout=subprocess.DEVNULL,
                 stderr=subprocess.DEVNULL,
             )
-            time.sleep(1)  # give a second for the above command to propagate
-            proc_status = mongod_exists(
+            proc_status = mongod_exists_wait(
                 controller="singularity", cname=sif_file)
+
             if proc_status is None:
                 # reading the logs from the file
+                logger.fatal('Problem finding singularity process')
                 try:
                     import json
                     err_string = open(
@@ -249,21 +320,16 @@ def singularity_handler(database_config, action, gangadir):
                                     f"Singularity container could not start because of: {log['attr']['error']}")
                 except:
                     pass
-                finally:
-                    print(f"The avail processes are: {[proc for proc in psutil.process_iter() if proc.name() == 'mongod']}")
-                    raise ContainerCommandError(
-                        message="For more information check the logs at $GANGADIR/logs/mongod-ganga.log",
-                        controller="singularity"
-                    )
+                import sys
+                sys.exit(1)
             logger.info(
                 f"Singularity gangaDB started on port: {database_config['port']}"
             )
     elif action == "quit":
         proc_status = mongod_exists(controller="singularity", cname=sif_file)
-        # if proc_status is not None or errored:
-        if proc_status is not None and proc_status.status() != "terminated":
+        if proc_status is not None:
             logger.debug(
-                f"mongod process killed was: {proc_status}", proc_status.status(), )
+                f"mongod process killed was: {proc_status}")
             logger.debug("stopping singularity container using: ",
                          stop_container)
             proc = subprocess.Popen(
@@ -337,8 +403,7 @@ def udocker_handler(database_config, action, gangadir):
                 stdout=subprocess.DEVNULL,
                 stderr=subprocess.DEVNULL,
             )
-            time.sleep(2)  # give a second for the above ommand to propagate
-            proc_status = mongod_exists(
+            proc_status = mongod_exists_wait(
                 controller="udocker", cname=database_config["containerName"]
             )
             if proc_status is None:
