@@ -1,21 +1,24 @@
-from __future__ import absolute_import
 
-from GangaCore.GPIDev.Base.Objects import GangaObject
-from GangaCore.GPIDev.Schema import Schema, Version, SimpleItem
-from GangaCore.GPIDev.Lib.GangaList.GangaList import makeGangaList
-
-from GangaCore.Core.exceptions import GangaException, GangaTypeError
-
-from GangaCore.GPIDev.Base.Proxy import stripProxy
-
-from GangaCore.Core.GangaRepository.Registry import Registry, RegistryKeyError
-
-from .RegistrySlice import RegistrySlice, config
-
-from .RegistrySliceProxy import RegistrySliceProxy, _wrap, _unwrap
 
 import GangaCore.Utility.logging
-logger = GangaCore.Utility.logging.getLogger()
+from GangaCore.GPIDev.Base.Proxy import stripProxy
+from GangaCore.GPIDev.Base.Objects import GangaObject
+from GangaCore.GPIDev.Schema import Schema, SimpleItem, Version
+from GangaCore.GPIDev.Lib.GangaList.GangaList import makeGangaList
+from GangaCore.Core.GangaRepository.Registry import RegistryKeyError
+from GangaCore.Core.exceptions import GangaException, GangaTypeError
+
+from .RegistrySlice import RegistrySlice, config
+from .RegistrySliceProxy import RegistrySliceProxy, _unwrap, _wrap
+from GangaCore.Utility.Config import getConfig
+from GangaCore.Utility.logging import getLogger
+
+logger = getLogger()
+
+if getConfig('Configuration')["repositorytype"] in ["Database", "CentralDatabase"]:
+    from GangaCore.Core.GangaRepository.DatabaseRegistry import Registry
+else:
+    from GangaCore.Core.GangaRepository.Registry import Registry
 
 class BoxMetadataObject(GangaObject):
 
@@ -156,6 +159,11 @@ class BoxRegistry(Registry):
         self._needs_metadata = True
         super(BoxRegistry, self).startup()
 
+    def shutdown(self, kill):
+        """
+        This allows us to clean up after the ShareDir on shutdown
+        """
+        super(BoxRegistry, self).shutdown(kill=kill)
 
 class BoxRegistrySlice(RegistrySlice):
 
@@ -246,9 +254,8 @@ class BoxRegistrySliceProxy(RegistrySliceProxy):
         Remove all objects from the box registry.
         """
 
-        items = stripProxy(self).objects.items()
+        items = list(stripProxy(self).objects.items())
         for id, obj in items:
             reg = obj._getRegistry()
             if not reg is None:
                 reg._remove(obj)
-
