@@ -1,5 +1,5 @@
-from __future__ import absolute_import
-from __future__ import print_function
+
+
 from GangaCore.GPIDev.Base import GangaObject
 from GangaCore.GPIDev.Schema import Schema, Version, SimpleItem, ComponentItem, FileItem, GangaFileItem
 from GangaCore.Utility.logging import getLogger
