@@ -29,7 +29,7 @@ def getLCGRootPath():
 
 # ------------------------------------------------
 # store Ganga version based on new git tag for this file
-_gangaVersion = '8.4.1'
+_gangaVersion = '8.5.0'
 _development = False
 
 # store a path to Ganga libraries
@@ -113,7 +113,7 @@ conf_config.addOption('ReleaseNotes', True, 'Flag to print out the relevent subs
 conf_config.addOption('used_versions_path', '~/.cache/Ganga/', 'Path to the directory to store the file listing the used ganga versions')
 conf_config.addOption('gangadir', expandvars(None, '~/gangadir'),
                  'Location of local job repositories and workspaces. Default is ~/gangadir but in somecases (such as LSF CNAF) this needs to be modified to point to the shared file system directory.', filter=GangaCore.Utility.Config.expandvars)
-conf_config.addOption('repositorytype', 'LocalXML', 'Type of the repository.', examples='LocalXML')
+conf_config.addOption('repositorytype', 'LocalXML', 'Type of the repository.', examples='LocalXML, Database')
 conf_config.addOption('lockingStrategy', 'UNIX', 'Type of locking strategy which can be used. UNIX or FIXED . default = UNIX')
 conf_config.addOption('workspacetype', 'LocalFilesystem',
                  'Type of workspace. Workspace is a place where input and output sandbox of jobs are stored. Currently the only supported type is LocalFilesystem.')
@@ -424,6 +424,7 @@ condor_config = makeConfig('Condor', 'Settings for Condor Batch system')
 
 condor_config.addOption('query_global_queues', True,
                  "Query global condor queues, i.e. use '-global' flag")
+condor_config.addOption('MaxBytes', "1000000", 'Set maximum bytes to display with peek()')
 
 # ------------------------------------------------
 # LSF
@@ -465,6 +466,10 @@ lsf_config.addOption('postexecute', tempstr, "String contains commands executing
 lsf_config.addOption('jobnameopt', 'J', "String contains option name for name of job in batch system")
 lsf_config.addOption('timeout', 600, 'Timeout in seconds after which a job is declared killed if it has not touched its heartbeat file. Heartbeat is touched every 30s so do not set this below 120 or so.')
 
+# illegal substring substition in job names
+lsf_config.addOption('jobnamesubstitution', [], "A list containing (1) a regular expression used to substitute illegal substrings in a job name, and (2) the substring to replace such occurences with.")
+
+
 # ------------------------------------------------
 # PBS
 pbs_config = makeConfig('PBS', 'internal PBS command line interface')
@@ -508,6 +513,10 @@ pbs_config.addOption('jobnameopt', 'N', "String contains option name for name of
 pbs_config.addOption('timeout', 600,
                  'Timeout in seconds after which a job is declared killed if it has not touched its heartbeat file. Heartbeat is touched every 30s so do not set this below 120 or so.')
 
+# illegal substring substition in job names
+pbs_config.addOption('jobnamesubstitution', ['[\s]', '_'], "A list containing (1) a regular expression used to substitute illegal substrings in a job name, and (2) the substring to replace such occurences with.")
+
+
 # ------------------------------------------------
 # SGE
 sge_config = makeConfig('SGE', 'internal SGE command line interface')
@@ -550,6 +559,9 @@ sge_config.addOption('postexecute', '', "String contains commands executing befo
 sge_config.addOption('jobnameopt', 'N', "String contains option name for name of job in batch system")
 sge_config.addOption('timeout', 600, 'Timeout in seconds after which a job is declared killed if it has not touched its heartbeat file. Heartbeat is touched every 30s so do not set this below 120 or so.')
 
+# illegal substring substition in job names
+sge_config.addOption('jobnamesubstitution', ['[\s:]', '_'], "A list containing (1) a regular expression used to substitute illegal substrings in a job name, and (2) the substring to replace such occurences with.")
+
 # ------------------------------------------------
 # Slurm
 slurm_config = makeConfig('Slurm', 'internal Slurm command line interface')
@@ -620,6 +632,10 @@ slurm_config.addOption('jobnameopt', 'J', "String contains option name for name
 slurm_config.addOption('timeout', 600,
                        'Timeout in seconds after which a job is declared killed if it has not touched its heartbeat file. Heartbeat is touched every 30s so do not set this below 120 or so.')
 
+# illegal substring substition in job names
+slurm_config.addOption('jobnamesubstitution', [], "A list containing (1) a regular expression used to substitute illegal substrings in a job name, and (2) the substring to replace such occurences with.")
+
+
 # ------------------------------------------------
 # Mergers
 merge_config = makeConfig('Mergers', 'parameters for mergers')
@@ -877,7 +893,9 @@ disp_config.addOption('jobs_status_colours',
                   'submitted': 'fg.orange',
                   'running': 'fg.green',
                   'completed': 'fg.blue',
-                  'failed': 'fg.red'
+                  'failed': 'fg.red',
+                  'completed_frozen' : 'fg.boldgrey',
+                  'failed_frozen' : 'fg.boldgrey'
                   },
                  'colours for jobs status')
 
@@ -969,7 +987,7 @@ db_config = makeConfig("DatabaseConfiguration", "Selection of database for ganga
 # db_config.addOption("container_rc", expandvars(
 #     None, '~/gangadir/container.rc'), "The location of container.rc file")
 db_config.addOption("controller", "docker",
-                    "Database Controller [Native, Docker, uDocker, Singularity]")
+                    "Database Controller [native, docker, udocker, singularity]")
 db_config.addOption("baseImage", "mongo", "Docker Image for the database")
 # db_config.addOption("containerName", container_name, "the identifier used to tag the docker container")
 db_config.addOption("username", "default", "username")
@@ -990,3 +1008,7 @@ db_config.addOption("password", "NotImplementedError", "password")
 db_config.addOption("host", "NotImplementedError", "host")
 db_config.addOption("port", "NotImplementedError", "port")
 db_config.addOption("dbname", "NotImplementedError", "name of database")
+
+google_config = makeConfig('Google','This controls the OAuth client used for connecting to Google')
+google_config.addOption("client_id", "", "The client ID of the Oauth client that you have created yourself")
+google_config.addOption("client_secret", "", "The client secret of the Oauth client that you have created yourself")
