@@ -204,3 +204,51 @@ def getAccessURLs(lfns, defaultSE = '', protocol = '', credential_requirements=N
     return myURLs
 
 exportToGPI('getAccessURLs', getAccessURLs, 'Functions')
+
+def getReplicas(inSet, credential_requirements=None):
+    """
+    Return a dict of files and their replicas.
+    lfns can be a string, a list or something with 
+    """
+    #Start off with some checks
+    lfns = []
+    if isinstance(inSet, str):
+        lfns = [inSet]
+    elif isinstance(inSet, list):
+        lfns = inSet
+    elif hasattr(inSet, 'getLFNs'):
+            lfns = inSet.getLFNs()
+    else:
+        raise GangaDiracError('You must supply, an LFN as a string, a list of LFNs or a GangaDataset with getLFNs() implemented')
+    reps = execute('getReplicas(%s)' % str(lfns), cred_req=credential_requirements)
+    if isinstance(lfns, list) and not len(reps['Successful'].keys()) == len(lfns):
+        logger.warning("Not successfully found a replica for all files! The following failed: %s" % reps['Failed'].keys())
+        
+    return reps['Successful']
+
+exportToGPI('getReplicas', getReplicas, 'Functions')
+
+
+def removeLFNs(lfns, credential_requirements=None):
+    """
+    Remove a list o lfns from Dirac storage
+    """
+    #Start off with some checks
+    lfns = []
+    if isinstance(inSet, str):
+        lfns = [inSet]
+    elif isinstance(inSet, list):
+        lfns = inSet
+    elif hasattr(inSet, 'getLFNs'):
+            lfns = inSet.getLFNs()
+    else:
+        raise GangaDiracError('You must supply, an LFN as a string, a list of LFNs or a GangaDataset with getLFNs() implemented')
+
+    res = execute('removeFile(%s)' % str(lfns), cred_req=credential_requirements)
+    if isinstance(lfns, list) and not len(reps['Successful'].keys()) == len(lfns):
+        logger.warning("Not successfully removed all files! The following failed: %s" % reps['Failed'].keys())
+        
+    return reps['Successful']
+
+exportToGPI('removeLFNs', removeLFNs, 'Functions')
+
