@@ -843,7 +843,7 @@ class DiracFile(IGangaFile):
         download_script = FileUtils.loadScript(script_location, '')
 
         script = """\n
-download_script='''\n###DOWNLOAD_SCRIPT###'''
+download_script=b'''\n###DOWNLOAD_SCRIPT###'''
 import subprocess
 dirac_env=###DIRAC_ENV###
 subprocess.Popen('''python -c "import sys\nexec(sys.stdin.read())"''', shell=True, env=dirac_env, stdin=subprocess.PIPE).communicate(download_script)
