@@ -82,7 +82,9 @@ def load_user(user_id):
 status_color = {
     "new": "info",
     "completed": "success",
+    "completed_frozen" : "success",
     "failed": "danger",
+    "failed_frozen" : "danger",
     "running": "primary",
     "submitted": "secondary",
     "killed": "warning"
@@ -1820,7 +1822,7 @@ def ping_internal():
 
         print("Internal API server not online (mostly because Ganga is booting up), retrying...")
         trials += 1
-        if trials > 10:
+        if trials > 20:
             return False
 
 
