@@ -10,7 +10,7 @@ import threading
 import stat
 import uuid
 from functools import wraps
-from StringIO import StringIO
+from io import StringIO, BytesIO
 
 from GangaCore.Core.exceptions import ApplicationConfigurationError, ApplicationPrepareError, GangaException
 from GangaCore.GPIDev.Adapters.IGangaFile import IGangaFile
@@ -23,7 +23,7 @@ from GangaCore.GPIDev.Lib.GangaList.GangaList import GangaList
 from GangaCore.GPIDev.Schema import Schema, Version, SimpleItem, GangaFileItem
 from GangaCore.Utility.logging import getLogger
 from GangaCore.Utility.files import expandfilename, fullpath
-
+from GangaCore.Utility.Config import getConfig
 from GangaDirac.Lib.Files.DiracFile import DiracFile
 from GangaDirac.Lib.Backends.DiracBase import DiracBase
 
@@ -31,6 +31,8 @@ from .GaudiExecUtils import getGaudiExecInputData, _exec_cmd, getTimestampConten
 
 logger = getLogger()
 
+configLHCb = getConfig('LHCb')
+
 def gaudiExecBuildLock(f):
     """ Method used to lock the build methods in GaudiExec so we don't run multiple builds in parallel.
     This is because each new build destorys the target.
@@ -122,6 +124,14 @@ class GaudiExec(IPrepareApp):
     Here the OptsFileWrapper script imports the extraOpts and the data.py describing the data to be run over and executes options in the global namespace with 'execfile'
     The OptsFileWrapper will _execute_ the first file in the job.application.options and will import all other opts files before executing this one.
 
+    If you want an argument after the run command then use the 'run_args' option. It takes a list of the arguments to use. For example
+
+        j.application.run_args = ['--quiet']
+
+    Makes the command
+        
+        ./run --quiet gaudirun.py optionsFile.py
+
     =================
     Get job metadata:
     =================
@@ -152,10 +162,11 @@ class GaudiExec(IPrepareApp):
         'uploadedInput': GangaFileItem(defvalue=None, hidden=1, doc='This stores the input for the job which has been pre-uploaded so that it gets to the WN'),
         'jobScriptArchive': GangaFileItem(defvalue=None, hidden=1, copyable=0, doc='This file stores the uploaded scripts which are generated fron this app to run on the WN'),
         'useGaudiRun':  SimpleItem(defvalue=True, doc='Should \'options\' be run as "python options.py data.py" rather than "gaudirun.py options.py data.py"'),
-        'platform' :    SimpleItem(defvalue='x86_64-slc6-gcc62-opt', typelist=[str], doc='Platform the application was built for'),
+        'platform' :    SimpleItem(defvalue=configLHCb['defaultPlatform'], typelist=[str], doc='Platform the application was built for'),
         'autoDBtags' :  SimpleItem(defvalue=False, doc='Automatically set database tags for MC'),
         'extraOpts':    SimpleItem(defvalue='', typelist=[str], doc='An additional string which is to be added to \'options\' when submitting the job'),
         'extraArgs':    SimpleItem(defvalue=[], typelist=[str], sequence=1, doc='Extra runtime arguments which are passed to the code running on the WN'),
+        'run_args' :    SimpleItem(defvalue = [], typelist=[list], doc='A list of arguments to pass to the lb-run script at run time. i.e. --quiet'),
         'getMetadata':  SimpleItem(defvalue=False, doc='Do you want to get the metadata from your jobs'),
 
         # Prepared job object
@@ -244,13 +255,23 @@ class GaudiExec(IPrepareApp):
             all_opts_files = self.getOptsFiles()
             for opts_file in all_opts_files:
                 if isinstance(opts_file, LocalFile):
+                    if opts_file.namePattern == 'data.py':
+                        raise ApplicationConfigurationError("Options file should not be named data.py to avoid conflict with generated inputdata file. Please rename your options and submit again.")
                     self.copyIntoPrepDir(path.join( opts_file.localDir, path.basename(opts_file.namePattern) ))
                 elif isinstance(opts_file, DiracFile):
+                    if opts_file.namePattern == 'data.py':
+                        raise ApplicationConfigurationError("Options file should not be named data.py to avoid conflict with generated inputdata file. Please rename your options and submit again.")
                     # NB safe to put it here as should have expressly setup a path for this job by now.
                     # We cannot _not_ place this here based upon the backend.
                     # Always have to put it here regardless of if we're on DIRAC or Local so prepared job can be copied.
                     opts_file.localDir=self.getSharedPath()
                     opts_file.get()
+                elif isinstance(opts_file, str):
+                    if 'data.py' in opts_file:
+                        raise ApplicationConfigurationError("Options file should not be named data.py to avoid conflict with generated inputdata file. Please rename your options and submit again.")
+                    new_file = LocalFile(opts_file)
+                    self.copyIntoPrepDir(path.join( new_file.localDir, path.basename(new_file.namePattern) ))
+                    opts_file = new_file
                 else:
                     raise ApplicationConfigurationError("Opts file type %s not yet supported please contact Ganga devs if you require this support" % getName(opts_file))
             self.post_prepare()
@@ -306,8 +327,8 @@ class GaudiExec(IPrepareApp):
                 tinfo = tarfile.TarInfo('__timestamp__')
                 tinfo.mtime = time.time()
                 fileobj = StringIO(getTimestampContent())
-                tinfo.size = fileobj.len
-                tar_file.addfile(tinfo, fileobj)
+                tinfo.size = len(fileobj.getvalue())
+                tar_file.addfile(tinfo, BytesIO(fileobj.getvalue().encode()))
         else:
             unique_name = master_job.application.jobScriptArchive.namePattern
 
@@ -324,8 +345,8 @@ class GaudiExec(IPrepareApp):
             tinfo = tarfile.TarInfo(extra_opts_file)
             tinfo.mtime = time.time()
             fileobj = StringIO(self.extraOpts)
-            tinfo.size = fileobj.len
-            tar_file.addfile(tinfo, fileobj)
+            tinfo.size = len(fileobj.getvalue())
+            tar_file.addfile(tinfo, BytesIO(fileobj.getvalue().encode()))
 
             if not self.useGaudiRun:
                 # Add the WN script for wrapping the job
@@ -333,8 +354,8 @@ class GaudiExec(IPrepareApp):
                 tinfo2 = tarfile.TarInfo(self.getWrapperScriptName())
                 tinfo2.mtime = time.time()
                 fileobj2 = StringIO(self.getWNPythonContents())
-                tinfo2.size = fileobj2.len
-                tar_file.addfile(tinfo2, fileobj2)
+                tinfo2.size = len(fileobj2.getvalue())
+                tar_file.addfile(tinfo2, BytesIO(fileobj2.getvalue().encode()))
 
 
     def cleanGangaTargetArea(self, this_build_target):
@@ -363,44 +384,80 @@ class GaudiExec(IPrepareApp):
         Args:
             masterappconfig (unknown): This is the output from the master_configure from the parent app
         """
-        # Lets test the inputs
-        opt_file = self.getOptsFiles()
-        dir_name = self.directory
         return (None, None)
 
-    def getOptsFiles(self):
+    def getOptsFiles(self, isPrepared = False):
         """
-        This function returns a sanitized absolute path to the self.options file from user input
+        This function returns a sanitized absolute path to the self.options file from user input.
+        If the app has previously been prepared as denoted by isPrepared then point to the sharedir
         """
-        for this_opt in self.options:
-            if isinstance(this_opt, LocalFile):
-                ## FIXME LocalFile should return the basename and folder in 2 attibutes so we can piece it together, now it doesn't
-                full_path = path.join(this_opt.localDir, this_opt.namePattern)
-                if not path.exists(full_path):
-                    raise ApplicationConfigurationError("Opts File: \'%s\' has been specified but does not exist please check and try again!" % full_path)
-            elif isinstance(this_opt, DiracFile):
-                pass
+
+        if isPrepared:
+            new_opts = []
+            share_path = self.is_prepared.path()
+            for this_opt in self.options:
+                if isinstance(this_opt, str):
+                    loc = path.join(share_path, path.basename(this_opt))
+                    if not path.exists(loc):
+                        raise ApplicationConfigurationError("Application previously configure but option file %s not found in the sharedir. Unprepare and resubmit." % path.basename(this_opt))
+                    new_opts.append(LocalFile(loc))
+                elif isinstance(this_opt, LocalFile):
+                    loc = path.join(share_path, this_opt.namePattern)
+                    if not path.exists(loc):
+                        raise ApplicationConfigurationError("Application previously configure but option file %s not found in the sharedir. Unprepare and resubmit." % this_opt.namePattern)
+                    new_opts.append(LocalFile(loc))
+                elif isinstance(this_opt, DiracFile):
+                    new_opts.append(this_opt)
+                else:
+                    logger.error("opts: %s" % self.options)
+                    raise ApplicationConfigurationError("Opts file type %s not yet supported please contact Ganga devs if you require this support" % getName(this_opt))
+            if new_opts or self.extraOpts:
+                return new_opts
             else:
-                logger.error("opts: %s" % self.options)
-                raise ApplicationConfigurationError("Opts file type %s not yet supported please contact Ganga devs if you require this support" % getName(this_opt))
-
-        if self.options or self.extraOpts:
-            return self.options
+                raise ApplicationConfigurationError("No options (as options files or extra options) has been specified. Please provide some.")
         else:
-            raise ApplicationConfigurationError("No options (as options files or extra options) has been specified. Please provide some.")
+            for this_opt in self.options:        
+                if isinstance(this_opt, str):
+                    #If it is a string then assume it is a local file.
+                    if not path.exists(this_opt):
+                        raise ApplicationConfigurationError("Opts File: \'%s\' has been specified but does not exist please check and try again!" % this_opt)
+                    new_opt = LocalFile(this_opt)
+                    this_opt = new_opt
+                if isinstance(this_opt, LocalFile):
+                    ## FIXME LocalFile should return the basename and folder in 2 attibutes so we can piece it together, now it doesn't
+                    full_path = path.join(this_opt.localDir, this_opt.namePattern)
+                    if not path.exists(full_path):
+                        raise ApplicationConfigurationError("Opts File: \'%s\' has been specified but does not exist please check and try again!" % full_path)
+                elif isinstance(this_opt, DiracFile):
+                    pass
+                else:
+                    logger.error("opts: %s" % self.options)
+                    raise ApplicationConfigurationError("Opts file type %s not yet supported please contact Ganga devs if you require this support" % getName(this_opt))
 
-    def getEnvScript(self):
+            if self.options or self.extraOpts:
+                return self.options
+            else:
+                raise ApplicationConfigurationError("No options (as options files or extra options) has been specified. Please provide some.")
+
+    def getEnvScript(self, isLbEnv):
         """
         Return the script which wraps the running command in a correct environment
         """
-        return 'export CMTCONFIG=%s; source LbLogin.sh --cmtconfig=%s && ' % (self.platform, self.platform)
+        if isLbEnv:
+            return 'source /cvmfs/lhcb.cern.ch/lib/LbEnv && source LbLogin.sh -c %s && ' % (self.platform)
+        else:
+            return 'export CMTCONFIG=%s; source /cvmfs/lhcb.cern.ch/lib/LbLogin.sh --cmtconfig=%s && ' % (self.platform, self.platform)
 
 
-    def getWNEnvScript(self):
+    def getWNEnvScript(self, isLbEnv):
         """
         Return the script to setup the correct env on a WN
         """
-        return 'export CMTCONFIG=%s; source $LHCb_release_area/LBSCRIPTS/prod/InstallArea/scripts/LbLogin.sh --cmtconfig=%s && ' % (self.platform, self.platform)
+        if isLbEnv:
+            return 'source /cvmfs/lhcb.cern.ch/lib/LbEnv && source LbLogin.sh -c %s && ' % (self.platform)
+        else:
+            return 'export CMTCONFIG=%s; source /cvmfs/lhcb.cern.ch/lib/LbLogin.sh --cmtconfig=%s && ' % (self.platform, self.platform)
+
 
     def execCmd(self, cmd):
         """
@@ -420,13 +477,17 @@ class GaudiExec(IPrepareApp):
         if not path.isdir(self.directory):
             raise GangaException("The given directory: '%s' doesn't exist!" % self.directory)
 
-        cmd_file = tempfile.NamedTemporaryFile(suffix='.sh', delete=False)
-        if not cmd.startswith('./run '):
-            cmd = './run ' + cmd
+        #Check if this was checked out with LbEnv or not
+        isLbEnv = False
+        with open(self.directory+'/Makefile', "r") as makefile:
+            if 'LbEnv' in makefile.read():
+                isLbEnv = True
+
+        cmd_file = tempfile.NamedTemporaryFile(suffix='.sh', delete=False, mode = "w")
 
         cmd_file.write("#!/bin/bash")
         cmd_file.write("\n")
-        cmd_file.write(self.getEnvScript())
+        cmd_file.write(self.getEnvScript(isLbEnv))
         cmd_file.write(cmd)
         cmd_file.flush()
         cmd_file.close()
@@ -439,7 +500,9 @@ class GaudiExec(IPrepareApp):
         # but this requires a build to have been run before we can use this command reliably... so we're just going to be explicit
 
         if not path.isfile(path.join(self.directory, 'build.%s' %self.platform, 'run')):
-            initialCommand = 'export CMTCONFIG=%s && source LbLogin.sh --cmtconfig=%s && make' % (self.platform, self.platform)
+            initialCommand = 'export CMTCONFIG=%s && source /cvmfs/lhcb.cern.ch/lib/LbLogin.sh --cmtconfig=%s && make' % (self.platform, self.platform)
+            if isLbEnv:
+                initialCommand = 'source /cvmfs/lhcb.cern.ch/lib/LbEnv && source LbLogin.sh -c %s && make' % (self.platform)
             rc, stdout, stderr = _exec_cmd(initialCommand, self.directory)
             if rc != 0:
                 logger.error("Failed to perform initial make on a Cmake based project")
@@ -450,11 +513,11 @@ class GaudiExec(IPrepareApp):
                 rc, stdout, stderr = _exec_cmd(cmd_file.name, self.directory)
         else:
             rc, stdout, stderr = _exec_cmd(cmd_file.name, self.directory)
-
         if rc != 0:
             logger.error("Failed to execute command: %s" % cmd_file.name)
             logger.error("Tried to execute command in: %s" % self.directory)
-            logger.error("StdErr: %s" % str(stdout))
+            logger.error("StdErr: %s" % str(stderr.decode()))
+            logger.error("StdOut: %s" % str(stdout.decode()))
             raise GangaException("Failed to Execute command")
 
         unlink(cmd_file.name)
@@ -491,7 +554,7 @@ class GaudiExec(IPrepareApp):
         # Whilst we are here let's store the application environment but ignore awkward ones
         env, envstdout, envstderr = self.execCmd('./run env')
         envDict = {}
-        for item in envstdout.split("\n"):
+        for item in envstdout.decode().split("\n"):
             if len(item.split("="))==2:
                 if item.split("=")[0] == 'XMLSUMMARYBASEROOT':
                     envDict[item.split("=")[0]] = item.split("=")[1]
