@@ -165,15 +165,14 @@ def prepareCommand(app):
             raise ApplicationConfigurationError("The filetype: %s is not yet supported for use as an opts file.\nPlease contact the Ganga devs is you wish this implemented." %
                                                 getName(opts_file))
 
-    #Check if this was checked out with LbEnv or not
-    isLbEnv = False
-    with open(app.directory+'/Makefile', "r") as makefile:
-        if 'LbEnv' in makefile.read():
-            isLbEnv = True
+    sourceEnv = app.getWNEnvScript(True)
 
-    sourceEnv = app.getWNEnvScript(isLbEnv)
+    #Get the options for the run script
+    run_args = ''
+    for _arg in app.run_args:
+        run_args += ' %s ' % _arg
 
-    run_cmd = ' export ganga_jobid=%s && ./run ' % app.getJobObject().fqid
+    run_cmd = ' export ganga_jobid=%s && ./run %s ' % (app.getJobObject().fqid, run_args)
 
     if not app.useGaudiRun:
         full_cmd = sourceEnv + run_cmd + 'python %s' % app.getWrapperScriptName()
@@ -491,13 +490,9 @@ class GaudiExecDiracRTHandler(IRuntimeHandler):
         j = app.getJobObject()
         for file_ in j.inputfiles:
             if isinstance(file_, DiracFile):
-                try:
-                    if file_.getReplicas():
-                        continue
-                    else:
+                if not file_.getReplicas():
                         raise GangaFileError("DiracFile inputfile with LFN %s has no replicas" % file_.lfn)
-                except GangaFileError as err:
-                    raise err
+
         all_opts_files = app.getOptsFiles(True)
         for opts_file in all_opts_files:
             if isinstance(opts_file, DiracFile):
@@ -641,6 +636,15 @@ class GaudiExecDiracRTHandler(IRuntimeHandler):
         # This code deals with the outputfiles as outputsandbox and outputdata for us
         lhcbdirac_outputfiles = lhcbdirac_outputfile_jdl(outputfiles)
 
+        #If we are doing virtualisation with a CVMFS location, check it is available
+        if job.virtualization and isinstance(job.virtualization.image, str):
+            if 'cvmfs' == job.virtualization.image.split('/')[1]:
+                tag_location = '/'+job.virtualization.image.split('/')[1]+'/'+job.virtualization.image.split('/')[2]+'/'
+                if 'Tag' in job.backend.settings:
+                    job.backend.settings['Tag'].append(tag_location)
+                else:
+                    job.backend.settings['Tag'] = [tag_location]
+
         # NOTE special case for replicas: replicate string must be empty for no
         # replication
         dirac_script = script_generator(lhcbdiracAPI_script_template(),
@@ -724,11 +728,12 @@ def flush_streams(pipe):
     '''
     with pipe.stdout or pipe.stderr:
         if pipe.stdout:
-            for next_line in iter(pipe.stdout.readline, b''):
+            for next_line in iter(pipe.stdout.readline, ''):
                 print("%s" % next_line, file=sys.stdout, end='')
                 sys.stdout.flush()
+            pipe.stdout.close()
         if pipe.stderr:
-            for next_line in iter(pipe.stderr.readline, b''):
+            for next_line in iter(pipe.stderr.readline, ''):
                 print("%s" % next_line, file=sys.stderr, end='')
                 sys.stderr.flush()
 
@@ -757,7 +762,7 @@ if __name__ == '__main__':
 
     # Execute the actual command on the WN
     # NB os.system caused the entire stream to be captured before being streamed in some cases
-    pipe = subprocess.Popen('###COMMAND###'+' '+' '.join(sys.argv[1:]), shell=True, stdin=subprocess.PIPE, stdout=subprocess.PIPE)
+    pipe = subprocess.Popen('###COMMAND###'+' '+' '.join(sys.argv[1:]), shell=True, stdin=subprocess.PIPE, stdout=subprocess.PIPE, universal_newlines=True)
 
     # Flush the stdout/stderr as the process is running correctly
     flush_streams(pipe)
